<?php
/**
 * Healthcoach Framework: theme variables storage
 *
 * @package	healthcoach
 * @since	healthcoach 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }

// Get theme variable
if (!function_exists('healthcoach_storage_get')) {
	function healthcoach_storage_get($var_name, $default='') {
		global $HEALTHCOACH_STORAGE;
		return isset($HEALTHCOACH_STORAGE[$var_name]) ? $HEALTHCOACH_STORAGE[$var_name] : $default;
	}
}

// Set theme variable
if (!function_exists('healthcoach_storage_set')) {
	function healthcoach_storage_set($var_name, $value) {
		global $HEALTHCOACH_STORAGE;
		$HEALTHCOACH_STORAGE[$var_name] = $value;
	}
}

// Check if theme variable is empty
if (!function_exists('healthcoach_storage_empty')) {
	function healthcoach_storage_empty($var_name, $key='', $key2='') {
		global $HEALTHCOACH_STORAGE;
		if (!empty($key) && !empty($key2))
			return empty($HEALTHCOACH_STORAGE[$var_name][$key][$key2]);
		else if (!empty($key))
			return empty($HEALTHCOACH_STORAGE[$var_name][$key]);
		else
			return empty($HEALTHCOACH_STORAGE[$var_name]);
	}
}

// Check if theme variable is set
if (!function_exists('healthcoach_storage_isset')) {
	function healthcoach_storage_isset($var_name, $key='', $key2='') {
		global $HEALTHCOACH_STORAGE;
		if (!empty($key) && !empty($key2))
			return isset($HEALTHCOACH_STORAGE[$var_name][$key][$key2]);
		else if (!empty($key))
			return isset($HEALTHCOACH_STORAGE[$var_name][$key]);
		else
			return isset($HEALTHCOACH_STORAGE[$var_name]);
	}
}

// Inc/Dec theme variable with specified value
if (!function_exists('healthcoach_storage_inc')) {
	function healthcoach_storage_inc($var_name, $value=1) {
		global $HEALTHCOACH_STORAGE;
		if (empty($HEALTHCOACH_STORAGE[$var_name])) $HEALTHCOACH_STORAGE[$var_name] = 0;
		$HEALTHCOACH_STORAGE[$var_name] += $value;
	}
}

// Concatenate theme variable with specified value
if (!function_exists('healthcoach_storage_concat')) {
	function healthcoach_storage_concat($var_name, $value) {
		global $HEALTHCOACH_STORAGE;
		if (empty($HEALTHCOACH_STORAGE[$var_name])) $HEALTHCOACH_STORAGE[$var_name] = '';
		$HEALTHCOACH_STORAGE[$var_name] .= $value;
	}
}

// Get array (one or two dim) element
if (!function_exists('healthcoach_storage_get_array')) {
	function healthcoach_storage_get_array($var_name, $key, $key2='', $default='') {
		global $HEALTHCOACH_STORAGE;
		if (empty($key2))
			return !empty($var_name) && !empty($key) && isset($HEALTHCOACH_STORAGE[$var_name][$key]) ? $HEALTHCOACH_STORAGE[$var_name][$key] : $default;
		else
			return !empty($var_name) && !empty($key) && isset($HEALTHCOACH_STORAGE[$var_name][$key][$key2]) ? $HEALTHCOACH_STORAGE[$var_name][$key][$key2] : $default;
	}
}

// Set array element
if (!function_exists('healthcoach_storage_set_array')) {
	function healthcoach_storage_set_array($var_name, $key, $value) {
		global $HEALTHCOACH_STORAGE;
		if (!isset($HEALTHCOACH_STORAGE[$var_name])) $HEALTHCOACH_STORAGE[$var_name] = array();
		if ($key==='')
			$HEALTHCOACH_STORAGE[$var_name][] = $value;
		else
			$HEALTHCOACH_STORAGE[$var_name][$key] = $value;
	}
}

// Set two-dim array element
if (!function_exists('healthcoach_storage_set_array2')) {
	function healthcoach_storage_set_array2($var_name, $key, $key2, $value) {
		global $HEALTHCOACH_STORAGE;
		if (!isset($HEALTHCOACH_STORAGE[$var_name])) $HEALTHCOACH_STORAGE[$var_name] = array();
		if (!isset($HEALTHCOACH_STORAGE[$var_name][$key])) $HEALTHCOACH_STORAGE[$var_name][$key] = array();
		if ($key2==='')
			$HEALTHCOACH_STORAGE[$var_name][$key][] = $value;
		else
			$HEALTHCOACH_STORAGE[$var_name][$key][$key2] = $value;
	}
}

// Add array element after the key
if (!function_exists('healthcoach_storage_set_array_after')) {
	function healthcoach_storage_set_array_after($var_name, $after, $key, $value='') {
		global $HEALTHCOACH_STORAGE;
		if (!isset($HEALTHCOACH_STORAGE[$var_name])) $HEALTHCOACH_STORAGE[$var_name] = array();
		if (is_array($key))
			healthcoach_array_insert_after($HEALTHCOACH_STORAGE[$var_name], $after, $key);
		else
			healthcoach_array_insert_after($HEALTHCOACH_STORAGE[$var_name], $after, array($key=>$value));
	}
}

// Add array element before the key
if (!function_exists('healthcoach_storage_set_array_before')) {
	function healthcoach_storage_set_array_before($var_name, $before, $key, $value='') {
		global $HEALTHCOACH_STORAGE;
		if (!isset($HEALTHCOACH_STORAGE[$var_name])) $HEALTHCOACH_STORAGE[$var_name] = array();
		if (is_array($key))
			healthcoach_array_insert_before($HEALTHCOACH_STORAGE[$var_name], $before, $key);
		else
			healthcoach_array_insert_before($HEALTHCOACH_STORAGE[$var_name], $before, array($key=>$value));
	}
}

// Push element into array
if (!function_exists('healthcoach_storage_push_array')) {
	function healthcoach_storage_push_array($var_name, $key, $value) {
		global $HEALTHCOACH_STORAGE;
		if (!isset($HEALTHCOACH_STORAGE[$var_name])) $HEALTHCOACH_STORAGE[$var_name] = array();
		if ($key==='')
			array_push($HEALTHCOACH_STORAGE[$var_name], $value);
		else {
			if (!isset($HEALTHCOACH_STORAGE[$var_name][$key])) $HEALTHCOACH_STORAGE[$var_name][$key] = array();
			array_push($HEALTHCOACH_STORAGE[$var_name][$key], $value);
		}
	}
}

// Pop element from array
if (!function_exists('healthcoach_storage_pop_array')) {
	function healthcoach_storage_pop_array($var_name, $key='', $defa='') {
		global $HEALTHCOACH_STORAGE;
		$rez = $defa;
		if ($key==='') {
			if (isset($HEALTHCOACH_STORAGE[$var_name]) && is_array($HEALTHCOACH_STORAGE[$var_name]) && count($HEALTHCOACH_STORAGE[$var_name]) > 0) 
				$rez = array_pop($HEALTHCOACH_STORAGE[$var_name]);
		} else {
			if (isset($HEALTHCOACH_STORAGE[$var_name][$key]) && is_array($HEALTHCOACH_STORAGE[$var_name][$key]) && count($HEALTHCOACH_STORAGE[$var_name][$key]) > 0) 
				$rez = array_pop($HEALTHCOACH_STORAGE[$var_name][$key]);
		}
		return $rez;
	}
}

// Inc/Dec array element with specified value
if (!function_exists('healthcoach_storage_inc_array')) {
	function healthcoach_storage_inc_array($var_name, $key, $value=1) {
		global $HEALTHCOACH_STORAGE;
		if (!isset($HEALTHCOACH_STORAGE[$var_name])) $HEALTHCOACH_STORAGE[$var_name] = array();
		if (empty($HEALTHCOACH_STORAGE[$var_name][$key])) $HEALTHCOACH_STORAGE[$var_name][$key] = 0;
		$HEALTHCOACH_STORAGE[$var_name][$key] += $value;
	}
}

// Concatenate array element with specified value
if (!function_exists('healthcoach_storage_concat_array')) {
	function healthcoach_storage_concat_array($var_name, $key, $value) {
		global $HEALTHCOACH_STORAGE;
		if (!isset($HEALTHCOACH_STORAGE[$var_name])) $HEALTHCOACH_STORAGE[$var_name] = array();
		if (empty($HEALTHCOACH_STORAGE[$var_name][$key])) $HEALTHCOACH_STORAGE[$var_name][$key] = '';
		$HEALTHCOACH_STORAGE[$var_name][$key] .= $value;
	}
}

// Call object's method
if (!function_exists('healthcoach_storage_call_obj_method')) {
	function healthcoach_storage_call_obj_method($var_name, $method, $param=null) {
		global $HEALTHCOACH_STORAGE;
		if ($param===null)
			return !empty($var_name) && !empty($method) && isset($HEALTHCOACH_STORAGE[$var_name]) ? $HEALTHCOACH_STORAGE[$var_name]->$method(): '';
		else
			return !empty($var_name) && !empty($method) && isset($HEALTHCOACH_STORAGE[$var_name]) ? $HEALTHCOACH_STORAGE[$var_name]->$method($param): '';
	}
}

// Get object's property
if (!function_exists('healthcoach_storage_get_obj_property')) {
	function healthcoach_storage_get_obj_property($var_name, $prop, $default='') {
		global $HEALTHCOACH_STORAGE;
		return !empty($var_name) && !empty($prop) && isset($HEALTHCOACH_STORAGE[$var_name]->$prop) ? $HEALTHCOACH_STORAGE[$var_name]->$prop : $default;
	}
}
?>